@@ -169,8 +169,10 @@ ario_util_format_title (ArioServerSong *server_song)
                 res = server_song->name;
         } else {
                 /* Original format is : "path/to/filename.extension" or http://path/to/address:port
-                 * We only want to display filename or http address */
-                if (!g_ascii_strncasecmp (server_song->file, "http://", 7)) {
+                 * or lastfm://path/to/address
+                 * We only want to display filename or http/last.fm address */
+                if (!g_ascii_strncasecmp (server_song->file, "http://", 7)
+                    || !g_ascii_strncasecmp (server_song->file, "lastfm://", 7)) {
                         res = server_song->file;
                 } else {
                         slash = g_strrstr (server_song->file, "/");
@@ -482,7 +484,7 @@ ario_util_format_keyword (const char *keyword)
         /* List of modifications done on the keuword used for the search */
         const gchar *to_remove[] = {"cd 1", "cd 2", "cd 3", "cd 4", "cd 5",
                 "cd1", "cd2", "cd3", "cd4", "cd5",
-                "disc", "disk", "disque", NULL};
+                "disc", "disk", "disque", "remastered", NULL};
 
         /* Normalize keyword */
         ret = g_utf8_normalize (keyword, -1, G_NORMALIZE_ALL);
