@@ -19,6 +19,7 @@
 
 #include "servers/ario-server.h"
 #include <gtk/gtk.h>
+#include <config.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdint.h>
@@ -39,22 +40,22 @@
 
 static guint ario_server_signals[SERVER_LAST_SIGNAL] = { 0 };
 
-char * ArioServerItemNames[MPD_TAG_NUM_OF_ITEM_TYPES] =
+char * ArioServerItemNames[ARIO_TAG_COUNT] =
 {
-        N_("Artist"),           // MPD_TAG_ITEM_ARTIST
-        N_("Album"),            // MPD_TAG_ITEM_ALBUM
-        N_("Title"),            // MPD_TAG_ITEM_TITLE
-        N_("Track"),            // MPD_TAG_ITEM_TRACK
-        NULL,                   // MPD_TAG_ITEM_NAME
-        N_("Genre"),            // MPD_TAG_ITEM_GENRE
-        N_("Date"),             // MPD_TAG_ITEM_DATE
-        N_("Composer"),         // MPD_TAG_ITEM_COMPOSER
-        N_("Performer"),        // MPD_TAG_ITEM_PERFORMER
-        NULL,                   // MPD_TAG_ITEM_COMMENT
-        NULL,                   // MPD_TAG_ITEM_DISC
-        N_("Filename"),         // MPD_TAG_ITEM_FILENAME
-        N_("Album Artist"),     // MPD_TAG_ITEM_ALBUMARTIST
-        N_("Any")               // MPD_TAG_ITEM_ANY
+        N_("Artist"),           // ARIO_TAG_ARTIST
+        N_("Album"),            // ARIO_TAG_ALBUM
+        N_("Album Artist"),     // ARIO_TAG_ALBUM_ARTIST
+        N_("Title"),            // ARIO_TAG_TITLE
+        N_("Track"),            // ARIO_TAG_TRACK
+        NULL,                   // ARIO_TAG_NAME
+        N_("Genre"),            // ARIO_TAG_GENRE
+        N_("Date"),             // ARIO_TAG_DATE
+        N_("Composer"),         // ARIO_TAG_COMPOSER
+        N_("Performer"),        // ARIO_TAG_PERFORMER
+        NULL,                   // ARIO_TAG_COMMENT
+        NULL,                   // ARIO_TAG_DISC
+        N_("Filename"),         // ARIO_TAG_FILENAME
+        N_("Any")               // ARIO_TAG_ANY
 };
 
 G_DEFINE_TYPE (ArioServer, ario_server, G_TYPE_OBJECT)
@@ -361,26 +362,6 @@ ario_server_update_status (void)
         return ARIO_SERVER_INTERFACE_GET_CLASS (interface)->update_status ();
 }
 
-char *
-ario_server_get_current_title (void)
-{
-        ARIO_LOG_FUNCTION_START;
-        if (interface->server_song)
-                return interface->server_song->title;
-        else
-                return NULL;
-}
-
-char *
-ario_server_get_current_name (void)
-{
-        ARIO_LOG_FUNCTION_START;
-        if (interface->server_song)
-                return interface->server_song->name;
-        else
-                return NULL;
-}
-
 ArioServerSong *
 ario_server_get_current_song_on_server (void)
 {
@@ -531,7 +512,7 @@ gboolean
 ario_server_is_paused (void)
 {
         ARIO_LOG_FUNCTION_START;
-        return (interface->state == MPD_STATUS_STATE_PAUSE) || (interface->state == MPD_STATUS_STATE_STOP);
+        return (interface->state == ARIO_STATE_PAUSE) || (interface->state == ARIO_STATE_STOP);
 }
 
 void
@@ -874,19 +855,19 @@ ario_server_song_get_tag (const ArioServerSong *song,
 {
         ARIO_LOG_FUNCTION_START;
         switch (tag) {
-        case MPD_TAG_ITEM_ARTIST: return song->artist;
-        case MPD_TAG_ITEM_ALBUM: return song->album;
-        case MPD_TAG_ITEM_ALBUMARTIST: return song->album_artist;
-        case MPD_TAG_ITEM_TITLE: return song->title;
-        case MPD_TAG_ITEM_TRACK: return song->track;
-        case MPD_TAG_ITEM_NAME: return song->name;
-        case MPD_TAG_ITEM_GENRE: return song->genre;
-        case MPD_TAG_ITEM_DATE: return song->date;
-        case MPD_TAG_ITEM_COMPOSER: return song->composer;
-        case MPD_TAG_ITEM_PERFORMER: return song->performer;
-        case MPD_TAG_ITEM_COMMENT: return song->comment;
-        case MPD_TAG_ITEM_DISC: return song->disc;
-        case MPD_TAG_ITEM_FILENAME: return song->file;
+        case ARIO_TAG_ARTIST: return song->artist;
+        case ARIO_TAG_ALBUM: return song->album;
+        case ARIO_TAG_ALBUM_ARTIST: return song->album_artist;
+        case ARIO_TAG_TITLE: return song->title;
+        case ARIO_TAG_TRACK: return song->track;
+        case ARIO_TAG_NAME: return song->name;
+        case ARIO_TAG_GENRE: return song->genre;
+        case ARIO_TAG_DATE: return song->date;
+        case ARIO_TAG_COMPOSER: return song->composer;
+        case ARIO_TAG_PERFORMER: return song->performer;
+        case ARIO_TAG_COMMENT: return song->comment;
+        case ARIO_TAG_DISC: return song->disc;
+        case ARIO_TAG_FILENAME: return song->file;
         default: return NULL;
         }
 }
@@ -894,12 +875,17 @@ ario_server_song_get_tag (const ArioServerSong *song,
 void
 ario_server_playlist_add_songs (const GSList *songs,
                                 const gint pos,
-                                const gboolean play)
+                                const PlaylistAction action)
 {
         ARIO_LOG_FUNCTION_START;
         const GSList *tmp;
         int end;
 
+        /* Start playing if needed */
+        if (action == PLAYLIST_REPLACE)  {
+                ario_server_clear ();
+        }
+
         end = ario_server_get_current_playlist_length ();
 
         if (pos >= 0) {
@@ -916,7 +902,7 @@ ario_server_playlist_add_songs (const GSList *songs,
         }
 
         /* Start playing if needed */
-        if (play) {
+        if (action == PLAYLIST_ADD_PLAY || action == PLAYLIST_REPLACE)  {
                 ario_server_do_play_pos (end);
         }
 }
@@ -924,7 +910,7 @@ ario_server_playlist_add_songs (const GSList *songs,
 void
 ario_server_playlist_add_dir (const gchar *dir,
                               const gint pos,
-                              const gboolean play)
+                              const PlaylistAction action)
 {
         ARIO_LOG_FUNCTION_START;
         GSList *tmp;
@@ -943,7 +929,7 @@ ario_server_playlist_add_dir (const gchar *dir,
         }
 
         /* Append all files to playlist */
-        ario_server_playlist_add_songs (char_songs, pos, play);
+        ario_server_playlist_add_songs (char_songs, pos, action);
         g_slist_free (char_songs);
         ario_server_free_file_list (files);
 }
@@ -951,7 +937,7 @@ ario_server_playlist_add_dir (const gchar *dir,
 void
 ario_server_playlist_add_criterias (const GSList *criterias,
                                     const gint pos,
-                                    const gboolean play,
+                                    const PlaylistAction action,
                                     const gint nb_entries)
 {
         ARIO_LOG_FUNCTION_START;
@@ -990,7 +976,7 @@ ario_server_playlist_add_criterias (const GSList *criterias,
         /* Add songs to playlist */
         ario_server_playlist_add_songs (filenames,
                                         pos,
-                                        play);
+                                        action);
 
         g_slist_foreach (filenames, (GFunc) g_free, NULL);
         g_slist_free (filenames);
@@ -998,16 +984,16 @@ ario_server_playlist_add_criterias (const GSList *criterias,
 
 void
 ario_server_playlist_append_songs (const GSList *songs,
-                                   const gboolean play)
+                                   const PlaylistAction action)
 {
         ARIO_LOG_FUNCTION_START;
         /* Add songs to playlist */
-        ario_server_playlist_add_songs (songs, -1, play);
+        ario_server_playlist_add_songs (songs, -1, action);
 }
 
 void
 ario_server_playlist_append_server_songs (const GSList *songs,
-                                          const gboolean play)
+                                          const PlaylistAction action)
 {
         ARIO_LOG_FUNCTION_START;
         const GSList *tmp;
@@ -1022,13 +1008,13 @@ ario_server_playlist_append_server_songs (const GSList *songs,
         }
 
         /* Add songs to playlist */
-        ario_server_playlist_add_songs (char_songs, -1, play);
+        ario_server_playlist_add_songs (char_songs, -1, action);
         g_slist_free (char_songs);
 }
 
 void
 ario_server_playlist_append_artists (const GSList *artists,
-                                     const gboolean play,
+                                     const PlaylistAction action,
                                      const gint nb_entries)
 {
         ARIO_LOG_FUNCTION_START;
@@ -1042,7 +1028,7 @@ ario_server_playlist_append_artists (const GSList *artists,
                 /* Create a criteria corresponding to artist */
                 criteria = NULL;
                 atomic_criteria = (ArioServerAtomicCriteria *) g_malloc0 (sizeof (ArioServerAtomicCriteria));
-                atomic_criteria->tag = MPD_TAG_ITEM_ARTIST;
+                atomic_criteria->tag = ARIO_TAG_ARTIST;
                 atomic_criteria->value = g_strdup (tmp->data);
 
                 criteria = g_slist_append (criteria, atomic_criteria);
@@ -1050,7 +1036,7 @@ ario_server_playlist_append_artists (const GSList *artists,
         }
 
         /* Add songs matching criteria to playlist */
-        ario_server_playlist_append_criterias (criterias, play, nb_entries);
+        ario_server_playlist_append_criterias (criterias, action, nb_entries);
 
         g_slist_foreach (criterias, (GFunc) ario_server_criteria_free, NULL);
         g_slist_free (criterias);
@@ -1058,20 +1044,52 @@ ario_server_playlist_append_artists (const GSList *artists,
 
 void
 ario_server_playlist_append_dir (const gchar *dir,
-                                 const gboolean play)
+                                 const PlaylistAction action)
 {
         ARIO_LOG_FUNCTION_START;
         /* Append all files in dir to playlist */
-        ario_server_playlist_add_dir (dir, -1, play);
+        ario_server_playlist_add_dir (dir, -1, action);
 }
 
 void
 ario_server_playlist_append_criterias (const GSList *criterias,
-                                       const gboolean play,
+                                       const PlaylistAction action,
                                        const gint nb_entries)
 {
         ARIO_LOG_FUNCTION_START;
         /* Append all songs matching criteria to playlist */
-        ario_server_playlist_add_criterias (criterias, -1, play, nb_entries);
+        ario_server_playlist_add_criterias (criterias, -1, action, nb_entries);
+}
+
+void
+ario_server_free_song (ArioServerSong *song)
+{
+        ARIO_LOG_FUNCTION_START;
+        if (song) {
+                g_free (song->file);
+                g_free (song->artist);
+                g_free (song->title);
+                g_free (song->album);
+                g_free (song->album_artist);
+                g_free (song->track);
+                g_free (song->name);
+                g_free (song->date);
+                g_free (song->genre);
+                g_free (song->composer);
+                g_free (song->performer);
+                g_free (song->disc);
+                g_free (song->comment);
+                g_free (song);
+        }
+}
+
+void
+ario_server_free_output (ArioServerOutput *output)
+{
+        ARIO_LOG_FUNCTION_START;
+        if (output) {
+                g_free (output->name);
+                g_free (output);
+        }
 }
 
