@@ -65,6 +65,8 @@ static void ario_shell_cmd_connect (GtkAction *action,
                                     ArioShell *shell);
 static void ario_shell_cmd_disconnect (GtkAction *action,
                                        ArioShell *shell);
+static void ario_shell_cmd_update (GtkAction *action,
+                                   ArioShell *shell);
 static void ario_shell_cmd_plugins (GtkAction *action,
                                     ArioShell *shell);
 static void ario_shell_cmd_preferences (GtkAction *action,
@@ -157,6 +159,9 @@ static GtkActionEntry shell_actions [] =
         { "FileDisconnect", GTK_STOCK_DISCONNECT, N_("_Disconnect"), "<control>D",
                 NULL,
                 G_CALLBACK (ario_shell_cmd_disconnect) },
+        { "FileServerUpdate", GTK_STOCK_REFRESH, N_("_Update database"), "<control>U",
+                NULL,
+                G_CALLBACK (ario_shell_cmd_update) },
         { "FileQuit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q",
                 NULL,
                 G_CALLBACK (ario_shell_cmd_quit) },
@@ -263,11 +268,7 @@ ario_shell_finalize (GObject *object)
         g_object_unref (shell->priv->cover_handler);
         g_object_unref (shell->priv->playlist_manager);
         g_object_unref (shell->priv->notification_manager);
-#ifdef ENABLE_EGGTRAYICON
-        gtk_widget_destroy (GTK_WIDGET (shell->priv->tray_icon));;
-#else
         g_object_unref (G_OBJECT (shell->priv->tray_icon));
-#endif
 
         g_object_unref (shell->priv->ui_manager);
         g_object_unref (shell->priv->actiongroup);
@@ -421,12 +422,7 @@ ario_shell_construct (ArioShell *shell,
         shell->priv->tray_icon = ario_tray_icon_new (shell->priv->actiongroup,
                                                      shell->priv->ui_manager,
                                                      shell);
-        /* Egg tray icon can be hidden*/
-#ifdef ENABLE_EGGTRAYICON
-        gtk_widget_show_all (GTK_WIDGET (shell->priv->tray_icon));
-        if (!ario_conf_get_boolean (PREF_TRAY_ICON, PREF_TRAY_ICON_DEFAULT))
-                gtk_widget_hide (GTK_WIDGET (shell->priv->tray_icon));
-#endif
+
         /* Initialize playlist manager */
         shell->priv->playlist_manager = ario_playlist_manager_get_instance ();
 
@@ -458,7 +454,7 @@ ario_shell_construct (ArioShell *shell,
         shell->priv->playlist = ario_playlist_new (shell->priv->ui_manager, shell->priv->actiongroup);
 
         /* Create source manager */
-        shell->priv->sourcemanager = ario_sourcemanager_get_instance (shell->priv->ui_manager, shell->priv->actiongroup);
+        shell->priv->sourcemanager = ario_source_manager_get_instance (shell->priv->ui_manager, shell->priv->actiongroup);
 
         /* Create vpaned (separation between upper part and plyalist) */
         shell->priv->vpaned = gtk_vpaned_new ();
@@ -575,7 +571,7 @@ ario_shell_shutdown (ArioShell *shell)
         ario_playlist_shutdown ();
 
         /* Shutdown the source manager */
-        ario_sourcemanager_shutdown ();
+        ario_source_manager_shutdown ();
 
         /* Shutdown the cover_manager */
         ario_cover_manager_shutdown (ario_cover_manager_get_instance ());
@@ -677,6 +673,11 @@ ario_shell_set_visibility (ArioShell *shell,
                         if (shell->priv->maximized)
                                 gtk_window_maximize (GTK_WINDOW (shell));
                         gtk_widget_show_all (GTK_WIDGET(shell));
+
+                        /* Restore vpaned position
+                         * This is in a g_timeout_add because there seems to have a bug (#2798748) if I call 
+                         * ario_shell_sync_paned directly. I really don't understand why but this seems to work...*/
+                         g_timeout_add (100, (GSourceFunc) ario_shell_sync_paned, shell);
                 } else {
                         /* Save window state, size and position */
                         shell->priv->maximized = ario_conf_get_boolean (PREF_WINDOW_MAXIMIZED, PREF_WINDOW_MAXIMIZED_DEFAULT);
@@ -686,6 +687,11 @@ ario_shell_set_visibility (ArioShell *shell,
                         gtk_window_get_size (GTK_WINDOW (shell),
                                              &shell->priv->window_w,
                                              &shell->priv->window_h);
+
+                        /* Save vpaned position */
+                        ario_conf_set_integer (PREF_VPANED_POSITION,
+                                               gtk_paned_get_position (GTK_PANED (shell->priv->vpaned)));
+
                         gtk_widget_hide (GTK_WIDGET(shell));
                 }
         }
@@ -715,6 +721,14 @@ ario_shell_cmd_disconnect (GtkAction *action,
         ario_server_disconnect ();
 }
 
+static void
+ario_shell_cmd_update (GtkAction *action,
+                       ArioShell *shell)
+{
+        ARIO_LOG_FUNCTION_START;
+        ario_server_update_db (NULL);
+}
+
 static void
 ario_shell_cmd_preferences (GtkAction *action,
                             ArioShell *shell)
@@ -794,8 +808,8 @@ ario_shell_server_song_set_title (ArioShell *shell)
         gchar *tmp;
 
         switch (ario_server_get_current_state ()) {
-        case MPD_STATUS_STATE_PLAY:
-        case MPD_STATUS_STATE_PAUSE:
+        case ARIO_STATE_PLAY:
+        case ARIO_STATE_PAUSE:
                 /* Window title containing song name */
                 tmp = ario_util_format_title (ario_server_get_current_song ());
                 window_title = g_strdup_printf ("Ario - %s", tmp);
@@ -980,8 +994,8 @@ ario_shell_sync_server (ArioShell *shell)
         gtk_action_set_visible (disconnect_action, shell->priv->connected);
 
         is_playing = ((shell->priv->connected)
-                      && ((ario_server_get_current_state () == MPD_STATUS_STATE_PLAY)
-                          || (ario_server_get_current_state () == MPD_STATUS_STATE_PAUSE)));
+                      && ((ario_server_get_current_state () == ARIO_STATE_PLAY)
+                          || (ario_server_get_current_state () == ARIO_STATE_PAUSE)));
 
         /* Set lyrics entry sensitivty */
         action = gtk_action_group_get_action (shell->priv->actiongroup,
@@ -1114,7 +1128,7 @@ ario_shell_cmd_plugins (GtkAction *action,
                                               GTK_RESPONSE_CLOSE,
                                               NULL);
         gtk_container_set_border_width (GTK_CONTAINER (window), 5);
-        gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (window)->vbox), 2);
+        gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (window))), 2);
         gtk_dialog_set_has_separator (GTK_DIALOG (window), FALSE);
 
         /* Connect signals for window destruction */
@@ -1129,7 +1143,7 @@ ario_shell_cmd_plugins (GtkAction *action,
 
         manager = ario_plugin_manager_new ();
         gtk_widget_show_all (GTK_WIDGET (manager));
-        gtk_container_add (GTK_CONTAINER (GTK_DIALOG (window)->vbox),
+        gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (window))),
                            manager);
 
         gtk_window_set_default_size (GTK_WINDOW (window), 300, 350);
